"""The module provides a function called print_lol(), which returns or not the items
in lists that may or may not include nested lists, and can be used with up to 3 arguments:
default (list), indented (list, True) or indented from a value (list, True, 2)."""


def print_lol(the_list, indent=False, level=0):
    """We go through the list, if there is another list inside the list, it will be displayed by calling
     the function itself in if. Use the arguments (list, True) for indented output or a value (list, True, 2)."""
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, indent, level + 1)
        else:
            if indent:
                for tab_stop in range(level):
                    print('\t', end='')
            print(each_item)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="nesterlists",
    version="1.0.0",
    license="MIT License",
    author="Marciodm",
    author_email="marcio0770@gmail.com",
    description="Returns items in lists that may or may not include nested lists.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Marciodm",
    packages=setuptools.find_packages(),
    classifiers=(
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
    ),
)
